@@ -22,7 +22,7 @@
 #include <QDBusConnection>
 #include <QDebug>
 
-#include "engine-common.h"
+#include "engine_common.h"
 
 EngineDevice* EngineDevice::instance = NULL;
 
@@ -40,10 +40,8 @@ void EngineDevice::power_device_get_devices()
     {
         const QDBusArgument &dbusArg = res.arguments().at(0).value<QDBusArgument>();
         dbusArg >> deviceNames;
-        qDebug()<<"get devices size!"<<deviceNames.size();
     }
     else {
-        qDebug()<<"No response!";
     }
     int len = deviceNames.size();
     for(int i = 0; i < len; i++)
@@ -73,14 +71,19 @@ EngineDevice::EngineDevice(QObject *parent) : QObject(parent)
     QDBusConnection::systemBus().connect(DBUS_SERVICE,DBUS_OBJECT,DBUS_SERVICE,
                                          QString("device-removed"),this,SLOT(power_device_remove(QDBusMessage)));
     settings = new QGSettings(GPM_SETTINGS_SCHEMA);
-    engine_policy_settings_cb();
+    connect(settings,SIGNAL(changed(const QString&)),this,SLOT(engine_policy_settings_cb(const QString&)));
+
+//    QDBusConnection::systemBus().connect(MYDBUS_SERVICE,MYDBUS_OBJECT,MYDBUS_SERVICE,
+//                                         QString("deviceadded"),this,SLOT(mypower_device_add(QString)));
+//    QDBusConnection::systemBus().connect(MYDBUS_SERVICE,MYDBUS_OBJECT,MYDBUS_SERVICE,
+//                                         QString("deviceremoved"),this,SLOT(mypower_device_removed(QString)));
 
-    connect(settings,SIGNAL(changed(const QString&)),this,SLOT(engine_policy_settings_cb()));
 }
 
-void EngineDevice::engine_policy_settings_cb()
+void EngineDevice::engine_policy_settings_cb(const QString& str)
 {
-    qDebug()<<"policy setting changed";
+    if(str != "iconPolicy")
+        return;
     QVariant var =settings->get(GPM_SETTINGS_KEY_POLICY);
     QString icon_policy_str = var.value<QString>();
     if(icon_policy_str == "always")
@@ -96,7 +99,37 @@ void EngineDevice::engine_policy_settings_cb()
     else if(icon_policy_str == "never")
         icon_policy = GPM_ICON_POLICY_NEVER;
 
-    qDebug()<<icon_policy;
+    power_device_recalculate_icon();
+}
+
+void EngineDevice::mypower_device_add(QString msg)
+{
+    DEVICE *dev = new DEVICE;
+    dev->m_dev.path = msg;
+    dev->m_dev.kind = UP_DEVICE_KIND_BATTERY;
+    dev->m_dev.warnlevel = (UpDeviceLevel)1;
+    dev->m_dev.Capacity = 88;
+    dev->m_dev.State = (UpDeviceState)1;
+
+    /*add to array*/
+    devices.append(dev);
+    /*connect notify signals*/
+    connect(dev,SIGNAL(device_property_changed(QDBusMessage,QString)),this,SLOT(power_device_change_callback(QDBusMessage,QString)));
+    /*recaculate state*/
+    Q_EMIT one_device_add(dev);
+}
+
+void EngineDevice::mypower_device_removed(QString msg)
+{
+    Q_FOREACH (auto item, devices)
+    {
+        if(item->m_dev.path == msg)
+        {
+            devices.removeOne(item);
+            Q_EMIT one_device_remove(item);
+            break;
+        }
+    }
 }
 
 void EngineDevice::power_device_add(QDBusMessage msg)
@@ -140,6 +173,7 @@ void EngineDevice::power_device_add(QDBusMessage msg)
         /*connect notify signals*/
         connect(dev,SIGNAL(device_property_changed(QDBusMessage,QString)),this,SLOT(power_device_change_callback(QDBusMessage,QString)));
         /*recaculate state*/
+        Q_EMIT one_device_add(dev);
 
     }
 }
@@ -152,8 +186,9 @@ void EngineDevice::power_device_remove(QDBusMessage msg)
         //list.removed
         {
             devices.removeOne(item);
-            delete item;
-            item = NULL;
+            Q_EMIT one_device_remove(item);
+//            delete item;
+//            item = NULL;
             break;
         }
 
@@ -248,7 +283,6 @@ void EngineDevice::power_device_change_callback(QDBusMessage msg,QString path)
     /* if battery change to display devices */
     /* judge state */
 
-    qDebug()<<"change callback-------"<<path;
     DEVICE *item = nullptr;
     Q_FOREACH (auto item_tmp, devices)
     {
@@ -321,6 +355,7 @@ bool EngineDevice::power_device_recalculate_icon()
     /*call a function to obtain icon*/
     QString icon;
     icon = power_device_get_icon();
+//    qDebug() << "power_device_recalculate_icon-----"<<icon;
     if(icon.isNull())
     {
         if(previous_icon.isNull())
@@ -360,90 +395,99 @@ QString EngineDevice::power_device_get_icon()
     }
 
     /* we try CRITICAL: BATTERY, UPS, MOUSE, KEYBOARD */
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_CRITICAL, false);
-    if (!icon.isNull()) {
-        return icon;
-    }
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_CRITICAL, false);
-    if (!icon.isNull()) {
-        return icon;
-    }
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_MOUSE, UP_DEVICE_LEVEL_CRITICAL, false);
-    if (!icon.isNull()) {
-        return icon;
-    }
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_KEYBOARD, UP_DEVICE_LEVEL_CRITICAL, false);
-    if (!icon.isNull()) {
-        return icon;
+    if (icon_policy == GPM_ICON_POLICY_CRITICAL || icon_policy == GPM_ICON_POLICY_ALWAYS)
+    {
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_CRITICAL, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_CRITICAL, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_MOUSE, UP_DEVICE_LEVEL_CRITICAL, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_KEYBOARD, UP_DEVICE_LEVEL_CRITICAL, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        if(icon_policy == GPM_ICON_POLICY_CRITICAL)
+        {
+            return QString();
+        }
     }
 
-    /* policy */
-    if (icon_policy == GPM_ICON_POLICY_CRITICAL) {
-        printf ("no devices critical, so no icon will be displayed.");
-        return QString();
-    }
 
     /* we try GPM_ENGINE_WARNING_LOW: BATTERY, UPS, MOUSE, KEYBOARD */
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_LOW, false);
-    if (!icon.isNull()) {
-        return icon;
-    }
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_LOW, false);
-    if (!icon.isNull()) {
-        return icon;
-    }
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_MOUSE, UP_DEVICE_LEVEL_LOW, false);
-    if (!icon.isNull()) {
-        return icon;
-    }
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_KEYBOARD, UP_DEVICE_LEVEL_LOW, false);
-    if (!icon.isNull()) {
-        return icon;
-    }
-    /* policy */
-    if (icon_policy == GPM_ICON_POLICY_LOW) {
-        printf ("no devices low, so no icon will be displayed.");
-        return QString();
+    if (icon_policy == GPM_ICON_POLICY_LOW || icon_policy == GPM_ICON_POLICY_ALWAYS)
+    {
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_LOW, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_LOW, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_MOUSE, UP_DEVICE_LEVEL_LOW, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_KEYBOARD, UP_DEVICE_LEVEL_LOW, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        if(icon_policy == GPM_ICON_POLICY_LOW)
+        {
+            return QString();
+        }
     }
 
     /* we try (DIS)CHARGING: BATTERY, UPS */
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_NONE, true);
-    if (!icon.isNull()) {
-        return icon;
-    }
+    if (icon_policy == GPM_ICON_POLICY_CHARGE || icon_policy == GPM_ICON_POLICY_ALWAYS)
+    {
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_NONE, true);
+        if (!icon.isNull()) {
+            return icon;
+        }
 
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_NONE, true);
-    if (!icon.isNull()) {
-        return icon;
-    }
-
-    /* policy */
-    if (icon_policy == GPM_ICON_POLICY_CHARGE) {
-        printf ("no devices (dis)charging, so no icon will be displayed.");
-        return QString();
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_NONE, true);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        if(icon_policy == GPM_ICON_POLICY_CHARGE)
+        {
+            return QString();
+        }
     }
 
     /* we try PRESENT: BATTERY, UPS */
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_NONE, true);
-    if (!icon.isNull()) {
+    if (icon_policy == GPM_ICON_POLICY_PRESENT || icon_policy == GPM_ICON_POLICY_ALWAYS)
+    {
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_NONE, false);
+        if (!icon.isNull()) {
             return icon;
+        }
+        icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_NONE, false);
+        if (!icon.isNull()) {
+            return icon;
+        }
+        if(icon_policy == GPM_ICON_POLICY_PRESENT)
+        {
+            return QString();
+        }
     }
-    icon = power_device_get_icon_exact (UP_DEVICE_KIND_UPS, UP_DEVICE_LEVEL_NONE, false);
+
+    //always
+    icon = power_device_get_icon_exact (UP_DEVICE_KIND_BATTERY, UP_DEVICE_LEVEL_NONE, false);
     if (!icon.isNull()) {
         return icon;
     }
-
-    /* policy */
-    if (icon_policy == GPM_ICON_POLICY_PRESENT) {
-        printf ("no devices present, so no icon will be displayed.");
-        return QString();
-    }
-
     /* we fallback to the ac_adapter icon */
-    printf ("Using fallback");
     return QString("gpm-ac-adapter");
 }
-
 /**
  * power_device_get_icon_exact:
  *
@@ -462,6 +506,7 @@ QString EngineDevice::power_device_get_icon_exact (UpDeviceKind device_kind, UpD
         if ((device->m_dev.kind == device_kind) && (device->m_dev.IsPresent)) {
             if (warning != UP_DEVICE_LEVEL_NONE) {
                 if (warning_temp == warning) {
+                    composite_device = device;
                     return engine_get_device_icon (device);
                 }
                 continue;
@@ -469,11 +514,13 @@ QString EngineDevice::power_device_get_icon_exact (UpDeviceKind device_kind, UpD
             if (use_state) {
 //                if (state == UP_DEVICE_STATE_CHARGING || state == UP_DEVICE_STATE_DISCHARGING) {
                 if ( state == UP_DEVICE_STATE_DISCHARGING) {
+                    composite_device = device;
                     return engine_get_device_icon (device);
                 }
 
                 continue;
             }
+            composite_device = device;
             return engine_get_device_icon (device);
         }
     }
@@ -499,7 +546,7 @@ bool EngineDevice::engine_recalculate_summary ()
         Q_EMIT engine_signal_summary_change(summary);
         return true;
     }
-    printf ("no change");
+//    printf ("no change");
     return false;
 }
 
@@ -538,7 +585,7 @@ QString EngineDevice::engine_get_summary ()
  *
  * Return value: The time string, e.g. "2 hours 3 minutes"
  **/
-QString EngineDevice::gpm_get_timestring (int time_secs)
+QString EngineDevice::engine_get_timestring (int time_secs)
 {
     int  hours;
     int  minutes;
@@ -602,7 +649,7 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
     QString kind_desc;
     uint time_to_full_round;
     uint time_to_empty_round;
-    QString time_to_full_str;
+//    QString time_to_full_str;
     QString time_to_empty_str;
     UpDeviceKind kind;
     UpDeviceState state;
@@ -631,24 +678,27 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
         return result;
     }
 
-
     time_to_full_round = precision_round_down (time_to_full, GPM_UP_TIME_PRECISION);
     time_to_empty_round = precision_round_down (time_to_empty, GPM_UP_TIME_PRECISION);
 
     if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
-
-        if (kind == UP_DEVICE_KIND_BATTERY && time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-            time_to_empty_str = gpm_get_timestring (time_to_empty_round);
-            result = time_to_empty_str;
-
-        } else {
+        if(percentage >= 100)
             result = tr("fully charged");
-        }
+        else
+            result = tr("charging");
+
+//        if (kind == UP_DEVICE_KIND_BATTERY && time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
+//            time_to_empty_str = engine_get_timestring (time_to_empty_round);
+//            result = time_to_empty_str;
+
+//        } else {
+//            result = tr("fully charged");
+//        }
 
     } else if (state == UP_DEVICE_STATE_DISCHARGING) {
 
         if (time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-            time_to_empty_str = gpm_get_timestring (time_to_empty_round);
+            time_to_empty_str = engine_get_timestring (time_to_empty_round);
             result = time_to_empty_str;
 
         } else {
@@ -657,34 +707,34 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
         }
 
     } else if (state == UP_DEVICE_STATE_CHARGING) {
+        result = tr("charging");
+//        if (time_to_full_round > GPM_UP_TEXT_MIN_TIME &&
+//            time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
 
-        if (time_to_full_round > GPM_UP_TEXT_MIN_TIME &&
-            time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
+//            /* display both discharge and charge time */
+//            time_to_full_str = engine_get_timestring (time_to_full_round);
+//            time_to_empty_str = engine_get_timestring (time_to_empty_round);
 
-            /* display both discharge and charge time */
-            time_to_full_str = gpm_get_timestring (time_to_full_round);
-            time_to_empty_str = gpm_get_timestring (time_to_empty_round);
+//            /* TRANSLATORS: the device is charging, and we have a time to full and empty */
+//            result = time_to_full_str;
+//        } else if (time_to_full_round > GPM_UP_TEXT_MIN_TIME) {
 
-            /* TRANSLATORS: the device is charging, and we have a time to full and empty */
-            result = time_to_full_str;
-        } else if (time_to_full_round > GPM_UP_TEXT_MIN_TIME) {
+//            /* display only charge time */
+//            time_to_full_str = engine_get_timestring (time_to_full_round);
 
-            /* display only charge time */
-            time_to_full_str = gpm_get_timestring (time_to_full_round);
+//            /* TRANSLATORS: device is charging, and we have a time to full and a percentage */
+//            result = time_to_full_str;
 
-            /* TRANSLATORS: device is charging, and we have a time to full and a percentage */
-            result = time_to_full_str;
+//        } else {
 
-        } else {
+//            /* TRANSLATORS: device is charging, but we only have a percentage */
+//            result = tr("charging(%1%)").arg(percentage);
 
-            /* TRANSLATORS: device is charging, but we only have a percentage */
-            result = tr("charging(%1%)").arg(percentage);
-
-        }
+//        }
 
     }  else {
-        printf ("in an undefined state we are not charging or "
-                 "discharging and the batteries are also not charged");
+//        printf ("in an undefined state we are not charging or "
+//                 "discharging and the batteries are also not charged");
         result = QString("%1(%2%)").arg(kind_desc).arg(percentage);
     }
     return result;
@@ -747,7 +797,7 @@ QString EngineDevice::engine_get_device_summary(DEVICE* dv)
     if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
 
         if (kind == UP_DEVICE_KIND_BATTERY && time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-            time_to_empty_str = gpm_get_timestring (time_to_empty_round);
+            time_to_empty_str = engine_get_timestring (time_to_empty_round);
             result = QString("Battery is fully charged.\nProvides %1 laptop runtime").arg(time_to_empty_str);
         } else {
             result = QString("%1 is fully charged").arg(kind_desc);
@@ -756,7 +806,7 @@ QString EngineDevice::engine_get_device_summary(DEVICE* dv)
     } else if (state == UP_DEVICE_STATE_DISCHARGING) {
 
         if (time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-            time_to_empty_str = gpm_get_timestring (time_to_empty_round);
+            time_to_empty_str = engine_get_timestring (time_to_empty_round);
             result = QString("%1 %2 remaining (%3%)").arg(kind_desc).arg(time_to_empty_str).arg(percentage);
 
         } else {
@@ -770,8 +820,8 @@ QString EngineDevice::engine_get_device_summary(DEVICE* dv)
             time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
 
             /* display both discharge and charge time */
-            time_to_full_str = gpm_get_timestring (time_to_full_round);
-            time_to_empty_str = gpm_get_timestring (time_to_empty_round);
+            time_to_full_str = engine_get_timestring (time_to_full_round);
+            time_to_empty_str = engine_get_timestring (time_to_empty_round);
 
             /* TRANSLATORS: the device is charging, and we have a time to full and empty */
             result = QString("%1 %2 until charged (%3%)\nProvides %4 battery runtime")
@@ -780,7 +830,7 @@ QString EngineDevice::engine_get_device_summary(DEVICE* dv)
         } else if (time_to_full_round > GPM_UP_TEXT_MIN_TIME) {
 
             /* display only charge time */
-            time_to_full_str = gpm_get_timestring (time_to_full_round);
+            time_to_full_str = engine_get_timestring (time_to_full_round);
 
             /* TRANSLATORS: device is charging, and we have a time to full and a percentage */
             result = QString("%1 %2 until charged (%3%)").arg(kind_desc).arg(time_to_full_str).arg(percentage);
@@ -959,11 +1009,11 @@ QString EngineDevice::engine_get_device_icon (DEVICE *device)
     } else if (kind == UP_DEVICE_KIND_UPS) {
         if (!is_present) {
             /* battery missing */
-            result.sprintf ("gpm-%s-missing", prefix);
-//            result.sprintf ("gpm-%s-missing", prefix.toStdString().c_str());
+//            result.sprintf ("gpm-%s-missing", prefix);
+            result.sprintf ("gpm-%s-missing", prefix.toStdString().c_str());
 
         } else if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
-            result.sprintf ("gpm-%s-100", prefix);
+            result.sprintf ("gpm-%s-100", prefix.toStdString().c_str());
 
         } else if (state == UP_DEVICE_STATE_CHARGING) {
             index_str = engine_get_device_icon_index (percentage);
@@ -1022,10 +1072,9 @@ QString EngineDevice::engine_get_device_icon (DEVICE *device)
 
     /* nothing matched */
     if (result.isNull()) {
-        printf ("nothing matched, falling back to default icon");
+//        printf ("nothing matched, falling back to default icon");
         result =  ("dialog-warning");
     }
-    qDebug()<<result;
     return result;
 }
 
