@@ -17,93 +17,94 @@
         <translation type="obsolete">help</translation>
     </message>
     <message>
-        <location filename="titlewidget.cpp" line="56"/>
-        <source>Power Statistics-device information</source>
+        <location filename="titlewidget.cpp" line="79"/>
+        <source>Power Information</source>
+        <oldsource>Power Statistics-device information</oldsource>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>UkpmWidget</name>
     <message>
-        <location filename="ukpm-widget.cpp" line="66"/>
+        <location filename="ukpm-widget.cpp" line="103"/>
         <source>AC adapter</source>
         <translation>AC adapter</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="70"/>
+        <location filename="ukpm-widget.cpp" line="107"/>
         <source>Laptop battery</source>
         <translation>Laptop battery</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="74"/>
+        <location filename="ukpm-widget.cpp" line="111"/>
         <source>UPS</source>
         <translation>UPS</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="78"/>
+        <location filename="ukpm-widget.cpp" line="115"/>
         <source>Monitor</source>
         <translation>Monitor</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="82"/>
+        <location filename="ukpm-widget.cpp" line="119"/>
         <source>Mouse</source>
         <translation>Mouse</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="86"/>
+        <location filename="ukpm-widget.cpp" line="123"/>
         <source>Keyboard</source>
         <translation>Keyboard</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="90"/>
+        <location filename="ukpm-widget.cpp" line="127"/>
         <source>PDA</source>
         <translation>PDA</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="94"/>
+        <location filename="ukpm-widget.cpp" line="131"/>
         <source>Cell phone</source>
         <translation>Cell phone</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="98"/>
+        <location filename="ukpm-widget.cpp" line="135"/>
         <source>Media player</source>
         <translation>Media player</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="102"/>
+        <location filename="ukpm-widget.cpp" line="139"/>
         <source>Tablet</source>
         <translation>Tablet</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="106"/>
+        <location filename="ukpm-widget.cpp" line="143"/>
         <source>Computer</source>
         <translation>Computer</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="166"/>
-        <location filename="ukpm-widget.cpp" line="280"/>
-        <location filename="ukpm-widget.cpp" line="1575"/>
+        <location filename="ukpm-widget.cpp" line="201"/>
+        <location filename="ukpm-widget.cpp" line="307"/>
+        <location filename="ukpm-widget.cpp" line="1928"/>
         <source>Charging</source>
         <translation>Charging</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="169"/>
-        <location filename="ukpm-widget.cpp" line="283"/>
-        <location filename="ukpm-widget.cpp" line="1578"/>
+        <location filename="ukpm-widget.cpp" line="204"/>
+        <location filename="ukpm-widget.cpp" line="310"/>
+        <location filename="ukpm-widget.cpp" line="1931"/>
         <source>Discharging</source>
         <translation>Discharging</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="172"/>
-        <location filename="ukpm-widget.cpp" line="286"/>
-        <location filename="ukpm-widget.cpp" line="1581"/>
+        <location filename="ukpm-widget.cpp" line="207"/>
+        <location filename="ukpm-widget.cpp" line="313"/>
+        <location filename="ukpm-widget.cpp" line="1934"/>
         <source>Empty</source>
         <translation>Empty</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="175"/>
-        <location filename="ukpm-widget.cpp" line="289"/>
-        <location filename="ukpm-widget.cpp" line="1584"/>
+        <location filename="ukpm-widget.cpp" line="210"/>
+        <location filename="ukpm-widget.cpp" line="316"/>
+        <location filename="ukpm-widget.cpp" line="1937"/>
         <source>Charged</source>
         <translation>Charged</translation>
     </message>
@@ -132,12 +133,12 @@
         <translation type="vanished">value</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="399"/>
+        <location filename="ukpm-widget.cpp" line="416"/>
         <source>Device</source>
         <translation>Device</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="401"/>
+        <location filename="ukpm-widget.cpp" line="418"/>
         <source>Type</source>
         <translation>Type</translation>
     </message>
@@ -146,17 +147,17 @@
         <translation type="vanished">PowerSupply</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="486"/>
+        <location filename="ukpm-widget.cpp" line="503"/>
         <source>Online</source>
         <translation>Online</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="404"/>
+        <location filename="ukpm-widget.cpp" line="421"/>
         <source>Vendor</source>
         <translation>Vendor</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="406"/>
+        <location filename="ukpm-widget.cpp" line="423"/>
         <source>Model</source>
         <translation>Model</translation>
     </message>
@@ -173,12 +174,12 @@
         <translation type="vanished">IsRechargeable</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="440"/>
+        <location filename="ukpm-widget.cpp" line="457"/>
         <source>State</source>
         <translation>State</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="445"/>
+        <location filename="ukpm-widget.cpp" line="462"/>
         <source>Energy</source>
         <translation>Energy</translation>
     </message>
@@ -195,7 +196,7 @@
         <translation type="vanished">EnergyRate</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="459"/>
+        <location filename="ukpm-widget.cpp" line="476"/>
         <source>Voltage</source>
         <translation>Voltage</translation>
     </message>
@@ -208,12 +209,12 @@
         <translation type="vanished">TimeToEmpty</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="477"/>
+        <location filename="ukpm-widget.cpp" line="494"/>
         <source>Percentage</source>
         <translation>Percentage</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="482"/>
+        <location filename="ukpm-widget.cpp" line="499"/>
         <source>Capacity</source>
         <translation>Capacity</translation>
     </message>
@@ -234,251 +235,257 @@
         <translation type="vanished">Statistics</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="948"/>
-        <location filename="ukpm-widget.cpp" line="1088"/>
+        <location filename="ukpm-widget.cpp" line="1210"/>
+        <location filename="ukpm-widget.cpp" line="1373"/>
         <source>graphic type:</source>
         <translation>graphic type:</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="951"/>
+        <location filename="ukpm-widget.cpp" line="1213"/>
         <source>charge</source>
         <translation>charge</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="951"/>
+        <location filename="ukpm-widget.cpp" line="1213"/>
         <source>charge-accurency</source>
         <translation>charge-accurency</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="951"/>
+        <location filename="ukpm-widget.cpp" line="1213"/>
         <source>discharge</source>
         <translation>discharge</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="951"/>
+        <location filename="ukpm-widget.cpp" line="1213"/>
         <source>discharge-accurency</source>
         <translation>discharge-accurency</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="956"/>
-        <location filename="ukpm-widget.cpp" line="1111"/>
         <source>spline</source>
-        <translation>spline</translation>
+        <translation type="vanished">spline</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="957"/>
-        <location filename="ukpm-widget.cpp" line="1112"/>
         <source>show datapoint</source>
-        <translation>show datapoint</translation>
+        <translation type="vanished">show datapoint</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1004"/>
-        <location filename="ukpm-widget.cpp" line="1166"/>
         <source>no data to show.</source>
-        <translation>no data to show.</translation>
+        <translation type="vanished">no data to show.</translation>
     </message>
     <message>
         <source>History</source>
         <translation type="vanished">History</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1090"/>
+        <location filename="ukpm-widget.cpp" line="1375"/>
         <source>time span:</source>
         <translation>time span:</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1095"/>
+        <location filename="ukpm-widget.cpp" line="1380"/>
         <source>rate</source>
         <translation>rate</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1095"/>
+        <location filename="ukpm-widget.cpp" line="1380"/>
         <source>energy</source>
         <translation>energy</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1095"/>
+        <location filename="ukpm-widget.cpp" line="1380"/>
         <source>charge-time</source>
         <translation>charge-time</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1095"/>
+        <location filename="ukpm-widget.cpp" line="1380"/>
         <source>discharge-time</source>
         <translation>discharge-time</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1098"/>
+        <location filename="ukpm-widget.cpp" line="1383"/>
         <source>ten minutes</source>
         <translation>ten minutes</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1098"/>
+        <location filename="ukpm-widget.cpp" line="1383"/>
         <source>two hours</source>
         <translation>two hours</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1098"/>
+        <location filename="ukpm-widget.cpp" line="1383"/>
         <source>six hours</source>
         <translation>six hours</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1098"/>
+        <location filename="ukpm-widget.cpp" line="1383"/>
         <source>one day</source>
         <translation>one day</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1098"/>
+        <location filename="ukpm-widget.cpp" line="1383"/>
         <source>one week</source>
         <translation>one week</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1144"/>
+        <location filename="ukpm-widget.cpp" line="1439"/>
         <source>elapsed time</source>
         <translation>elapsed time</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="620"/>
-        <location filename="ukpm-widget.cpp" line="660"/>
+        <location filename="ukpm-widget.cpp" line="711"/>
+        <location filename="ukpm-widget.cpp" line="800"/>
         <source>adjust factor</source>
         <translation>adjust factor</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="178"/>
-        <location filename="ukpm-widget.cpp" line="292"/>
-        <location filename="ukpm-widget.cpp" line="1587"/>
+        <location filename="ukpm-widget.cpp" line="213"/>
+        <location filename="ukpm-widget.cpp" line="319"/>
+        <location filename="ukpm-widget.cpp" line="1940"/>
         <source>PendingCharge</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="181"/>
-        <location filename="ukpm-widget.cpp" line="295"/>
-        <location filename="ukpm-widget.cpp" line="1590"/>
+        <location filename="ukpm-widget.cpp" line="216"/>
+        <location filename="ukpm-widget.cpp" line="322"/>
+        <location filename="ukpm-widget.cpp" line="1943"/>
         <source>PendingDischarge</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="396"/>
+        <location filename="ukpm-widget.cpp" line="413"/>
         <source>Attribute</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="396"/>
+        <location filename="ukpm-widget.cpp" line="413"/>
         <source>Value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="408"/>
+        <location filename="ukpm-widget.cpp" line="425"/>
         <source>Serial number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="410"/>
+        <location filename="ukpm-widget.cpp" line="427"/>
         <source>Supply</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="419"/>
+        <location filename="ukpm-widget.cpp" line="436"/>
         <source>Refreshed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="427"/>
+        <location filename="ukpm-widget.cpp" line="444"/>
         <source>Present</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="433"/>
+        <location filename="ukpm-widget.cpp" line="450"/>
         <source>Rechargeable</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="447"/>
+        <location filename="ukpm-widget.cpp" line="464"/>
         <source>Energy when full</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="448"/>
+        <location filename="ukpm-widget.cpp" line="465"/>
         <source>Energy (design)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="464"/>
+        <location filename="ukpm-widget.cpp" line="481"/>
         <source>Time to full</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="468"/>
+        <location filename="ukpm-widget.cpp" line="485"/>
         <source>Time to empty</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="501"/>
+        <location filename="ukpm-widget.cpp" line="521"/>
         <source>history</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="508"/>
+        <location filename="ukpm-widget.cpp" line="532"/>
         <source>statistics</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="623"/>
-        <location filename="ukpm-widget.cpp" line="643"/>
-        <location filename="ukpm-widget.cpp" line="663"/>
-        <location filename="ukpm-widget.cpp" line="682"/>
+        <location filename="ukpm-widget.cpp" line="714"/>
+        <location filename="ukpm-widget.cpp" line="757"/>
+        <location filename="ukpm-widget.cpp" line="803"/>
+        <location filename="ukpm-widget.cpp" line="846"/>
         <source>battery power</source>
         <translation>battery power</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="640"/>
-        <location filename="ukpm-widget.cpp" line="679"/>
+        <location filename="ukpm-widget.cpp" line="754"/>
+        <location filename="ukpm-widget.cpp" line="840"/>
         <source>Predict Accurency</source>
         <translation>Predict Accurency</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="1062"/>
+        <location filename="ukpm-widget.cpp" line="1219"/>
+        <location filename="ukpm-widget.cpp" line="1392"/>
+        <source>show line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ukpm-widget.cpp" line="1220"/>
+        <location filename="ukpm-widget.cpp" line="1393"/>
+        <source>show data points</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ukpm-widget.cpp" line="1345"/>
         <source>detail</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="453"/>
-        <location filename="ukpm-widget.cpp" line="738"/>
+        <location filename="ukpm-widget.cpp" line="470"/>
+        <location filename="ukpm-widget.cpp" line="978"/>
         <source>Rate</source>
         <translation>Rate</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="759"/>
+        <location filename="ukpm-widget.cpp" line="995"/>
         <source>Charge</source>
         <translation>Charge</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.cpp" line="780"/>
-        <location filename="ukpm-widget.cpp" line="812"/>
+        <location filename="ukpm-widget.cpp" line="1016"/>
+        <location filename="ukpm-widget.cpp" line="1059"/>
         <source>Predict Time</source>
         <translation>Predict Time</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.h" line="110"/>
+        <location filename="ukpm-widget.h" line="124"/>
         <source>s</source>
         <translation>s</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.h" line="112"/>
+        <location filename="ukpm-widget.h" line="126"/>
         <source>m</source>
         <translation>m</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.h" line="114"/>
+        <location filename="ukpm-widget.h" line="128"/>
         <source>h</source>
         <translation>h</translation>
     </message>
     <message>
-        <location filename="ukpm-widget.h" line="119"/>
+        <location filename="ukpm-widget.h" line="133"/>
         <source>yes</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="ukpm-widget.h" line="119"/>
+        <location filename="ukpm-widget.h" line="133"/>
         <source>no</source>
         <translation></translation>
     </message>
